@@ -201,4 +201,16 @@ class MultiplesExperimentos:
             fig_plot.plot(range(1, cantidad_experimentos),
                           self.resultados_divergencia["visitas_regiones_no_preferidas"])
 
+        elif grafica is 'pendientes_distancias_velocidad':
+            fig_plot.plot(range(1, cantidad_experimentos),
+                          self.resultados_pendientes_regresion_lineal['Velocidad'], 'o')
+            fig_plot.plot(range(1, cantidad_experimentos),
+                          self.resultados_pendientes_regresion_lineal['Velocidad'])
+
+        elif grafica is 'pendientes_distancias_aceleracion':
+            fig_plot.plot(range(1, cantidad_experimentos),
+                          self.resultados_pendientes_regresion_lineal['Aceleracion'], 'o')
+            fig_plot.plot(range(1, cantidad_experimentos),
+                          self.resultados_pendientes_regresion_lineal['Aceleracion'])
+
         return fig
